@@ -31,7 +31,7 @@
 #define PRINTERVAL 20 /** Print Progress Interval (seconds) */
 #define CRASHFILE "savedstate.sav"
 #define VERSION_MAJOR 0
-#define VERSION_MINOR 6
+#define VERSION_MINOR 8
 
 /** alarmInterrupt is used to print out the progress at specific intervals */
 static void
@@ -186,7 +186,7 @@ main(int argc, char** argv) {
 
     case 'v':
       printf("pdfcrack version %d.%d\n", VERSION_MAJOR, VERSION_MINOR);
-      break;
+      return 0;
 
     default:
       printHelp(argv[0]);
@@ -261,17 +261,21 @@ main(int argc, char** argv) {
       ret = 4;
       goto out1;
     }
-    else if(e->revision > 3 || e->revision < 2) {
+    else if(e->revision < 2 || (strcmp(e->s_handler,"Standard") != 0)) {
       fprintf(stderr, "The specific version is not supported\n");
       ret = 5;
       goto out1;
-    }
+      }
   }
 
   if(fclose(file)) {
     fprintf(stderr, "Error: closing file %s\n", inputfile);
   }
 
+  if(minpw > maxpw) {
+    fprintf(stderr, "Warning: minimum pw-length bigger than max\n");
+  }
+
   if(wordlistfile) {
     if((wordlist = fopen(wordlistfile, "r")) == 0) {
       fprintf(stderr,"Error: file %s not found\n", wordlistfile);
