@@ -128,10 +128,10 @@ setCharset(const char *cs, const unsigned int minPw,
   if(!recovery) {
     /** This should already be set if we are loading from a saved state */
     if(cs)
-      charset = (uint8_t*)cs;
+      charset = (const uint8_t*)cs;
     else
       charset = stdchars;
-    charsetLen = strlen((char*)charset);
+    charsetLen = strlen((const char*)charset);
 
     /** Make sure that max- and min-password is smaller than 32 */
     if(maxPw < PASSLENGTH)
@@ -150,6 +150,8 @@ setCharset(const char *cs, const unsigned int minPw,
       else
 	password[i] = -1;
     }
+    while(i < PASSLENGTH-1)
+      password[i++] = -1;
   }
   /** Put terminator (-1) at the last position */
   password[PASSLENGTH-1] = -1;
