@@ -47,7 +47,7 @@ pad[32] = {
 /** buffers for stuff that we can precompute before the actual cracking */
 static uint8_t *encKeyWorkSpace;
 static uint8_t password_user[32];
-static const uint8_t *rev3TestKey;
+static uint8_t *rev3TestKey;
 static unsigned int ekwlen;
 
 /** points to the current password in clear-text */
@@ -522,9 +522,9 @@ initPDFCrack(const EncData *e, const uint8_t *upw, const bool user,
   nrprocessed = 0;
   workWithUser = user;
   crackDone = false;
-  setrc4DecryptMethod((unsigned int)e->length);
+  setrc4DecryptMethod((const unsigned int)e->length);
   if(upw) {
-    upwlen = strlen((char*)upw);
+    upwlen = strlen((const char*)upw);
     if(upwlen > 32)
       upwlen = 32;
     memcpy(password_user, upw, upwlen);
@@ -547,7 +547,7 @@ initPDFCrack(const EncData *e, const uint8_t *upw, const bool user,
       knownPassword = isUserPasswordRev2();
     }
   }
-  else if(e->revision == 3) {
+  else if(e->revision >= 3) {
     memcpy(buf, pad, 32);
     memcpy(buf + 32, e->fileID, e->fileIDLen);
     tmp = malloc(sizeof(uint8_t)*16);
