@@ -441,7 +441,7 @@ parseEncrypObject(FILE *file, EncData *e) {
       case 'E':
 	if(isWord(file, "ncryptMetadata")) {
 	  ungetc(parseWhiteSpace(file), file);
-	  if(isWord(file, "true"))
+	  if(isWord(file, "false"))
 	    fe = true;
 	}
 	break;
@@ -456,7 +456,12 @@ parseEncrypObject(FILE *file, EncData *e) {
 	}
       case 'L':
 	if(isWord(file, "ength")) {
-	  e->length = parseIntWithC(file,parseWhiteSpace(file));
+	  int tmp_l = parseIntWithC(file,parseWhiteSpace(file));
+	  if(!fl) { 
+	    /* BZZZT!!  This is sooo wrong but will work for most cases.
+	       only use the first length we stumble upon */
+	    e->length = tmp_l;
+	  }
 	  fl = true;
 	}
 	break;
@@ -505,7 +510,7 @@ parseEncrypObject(FILE *file, EncData *e) {
   if(!fv)
     e->version = 0;
 
-  if(e->version == 4)
+  if(strcmp(e->s_handler,"Standard") != 0)
     return true;
 
   return ff & fo && fp && fr && fu;
